@@ -10,11 +10,9 @@ module Elasticsearch
       #
       # @option arguments [String] :name A benchmark name
       #
-      # @see http://www.elasticsearch.org/guide/en/elasticsearch/reference/master/search-benchmark.html
+      # @see http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-benchmark.html
       #
       def abort_benchmark(arguments={})
-        valid_params = [
-           ]
         method = HTTP_POST
         path   = "_bench/abort/#{arguments[:name]}"
         params = {}
