@@ -5,29 +5,36 @@ module Elasticsearch
 
         # Return information about installed plugins
         #
-        # @option arguments [Boolean] :local Return local information, do not retrieve the state from master node
-        #                                    (default: false)
+        # @option arguments [String] :format a short version of the Accept header, e.g. json, yaml
+        # @option arguments [Boolean] :local Return local information, do not retrieve the state from master node (default: false)
         # @option arguments [Time] :master_timeout Explicit operation timeout for connection to master node
         # @option arguments [List] :h Comma-separated list of column names to display
         # @option arguments [Boolean] :help Return help information
+        # @option arguments [List] :s Comma-separated list of column names or column aliases to sort by
         # @option arguments [Boolean] :v Verbose mode. Display column headers
         #
-        # @see http://www.elastic.co/guide/en/elasticsearch/reference/master/cat-plugins.html
+        # @see http://www.elastic.co/guide/en/elasticsearch/reference/current/cat-plugins.html
         #
         def plugins(arguments={})
-          valid_params = [
-            :local,
-            :master_timeout,
-            :h,
-            :help,
-            :v ]
           method = 'GET'
-          path   = "/_cat/plugins"
-          params = Utils.__validate_and_extract_params arguments, valid_params
+          path   = "_cat/plugins"
+          params = Utils.__validate_and_extract_params arguments, ParamsRegistry.get(__method__)
           body   = nil
 
           perform_request(method, path, params, body).body
         end
+
+        # Register this action with its valid params when the module is loaded.
+        #
+        # @since 6.2.0
+        ParamsRegistry.register(:plugins, [
+            :format,
+            :local,
+            :master_timeout,
+            :h,
+            :help,
+            :s,
+            :v ].freeze)
       end
     end
   end
