@@ -10,23 +10,26 @@ module Elasticsearch
         #
         #     client.cluster.pending_tasks
         #
-        # @option arguments [Boolean] :local Return local information, do not retrieve the state from master node
-        #                                    (default: false)
+        # @option arguments [Boolean] :local Return local information, do not retrieve the state from master node (default: false)
         # @option arguments [Time] :master_timeout Specify timeout for connection to master
         #
-        # @see http://www.elasticsearch.org/guide/en/elasticsearch/reference/master/cluster-pending.html
+        # @see http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cluster-pending.html
         #
         def pending_tasks(arguments={})
-          valid_params = [
-            :local,
-            :master_timeout ]
           method = HTTP_GET
-          path   = "/_cluster/pending_tasks"
-          params = Utils.__validate_and_extract_params arguments, valid_params
+          path   = "_cluster/pending_tasks"
+          params = Utils.__validate_and_extract_params arguments, ParamsRegistry.get(__method__)
           body   = nil
 
           perform_request(method, path, params, body).body
         end
+
+        # Register this action with its valid params when the module is loaded.
+        #
+        # @since 6.2.0
+        ParamsRegistry.register(:pending_tasks, [
+            :local,
+            :master_timeout ].freeze)
       end
     end
   end
