@@ -14,6 +14,12 @@ module Elasticsearch
 
         perform_request(method, path, params, body).body
       end
+
+      # Register this action with its valid params when the module is loaded.
+      #
+      # @since 6.2.0
+      ParamsRegistry.register(:info, [
+      ].freeze)
     end
   end
 end
