@@ -14,7 +14,7 @@ require 'elasticsearch/extensions/test/startup_shutdown'
 require 'elasticsearch/extensions/test/profiling' unless JRUBY
 
 # Skip features
-skip_features = 'stash_in_path,requires_replica'
+skip_features = 'stash_in_path,requires_replica,headers,warnings,default_shards'
 SKIP_FEATURES = ENV.fetch('TEST_SKIP_FEATURES', skip_features)
 
 # Turn configuration
@@ -23,12 +23,14 @@ Turn.config.format = :pretty
 
 # Launch test cluster
 #
-Elasticsearch::Extensions::Test::Cluster.start(nodes: 1) if ENV['SERVER'] and not Elasticsearch::Extensions::Test::Cluster.running?
+if ENV['SERVER'] and not Elasticsearch::Extensions::Test::Cluster.running?
+  Elasticsearch::Extensions::Test::Cluster.start
+end
 
 # Register `at_exit` handler for server shutdown.
 # MUST be called before requiring `test/unit`.
 #
-at_exit { Elasticsearch::Extensions::Test::Cluster.stop if ENV['SERVER'] }
+at_exit { Elasticsearch::Extensions::Test::Cluster.stop if ENV['SERVER'] and Elasticsearch::Extensions::Test::Cluster.running? }
 
 class String
   # Reset the `ansi` method on CI
@@ -76,11 +78,13 @@ tracer.formatter = proc { |severity, datetime, progname, msg| "#{msg}\n" }
 #
 #     ruby -I lib:test -r ./tmp/my_special_client.rb test/integration/yaml_test_runner.rb
 #
-url = ENV.fetch('TEST_CLUSTER_URL', "http://localhost:#{ENV['TEST_CLUSTER_PORT'] || 9250}")
+url = ENV['TEST_CLUSTER_URL'] || ENV['TEST_ES_SERVER']
+url = "http://localhost:#{ENV['TEST_CLUSTER_PORT'] || 9250}" unless url
 $client ||= Elasticsearch::Client.new url: url
+$helper_client ||= Elasticsearch::Client.new url: url
 
 $client.transport.logger = logger unless ENV['QUIET'] || ENV['CI']
-$client.transport.tracer = tracer if ENV['CI']
+# $client.transport.tracer = tracer if ENV['CI']
 
 # Store Elasticsearch version
 #
@@ -128,6 +132,7 @@ end
 
 module Elasticsearch
   module YamlTestSuite
+    $last_response = ''
     $results = {}
     $stash   = {}
 
@@ -138,7 +143,7 @@ module Elasticsearch
 
       def symbolize_keys(object)
         if object.is_a? Hash
-          object.reduce({}) { |memo,(k,v)| memo[k.to_sym] = symbolize_keys(v); memo }
+          object.reduce({}) { |memo,(k,v)| memo[k.to_s.to_sym] = symbolize_keys(v); memo }
         else
           object
         end
@@ -180,7 +185,7 @@ module Elasticsearch
 
         $stderr.puts "ARGUMENTS: #{arguments.inspect}" if ENV['DEBUG']
 
-        $results[test.hash] = namespace.reduce($client) do |memo, current|
+        $last_response = namespace.reduce($client) do |memo, current|
           unless current == namespace.last
             memo = memo.send(current)
           else
@@ -188,12 +193,18 @@ module Elasticsearch
           end
           memo
         end
+
+        $results[test.hash] = $last_response
       end
 
-      def evaluate(test, property)
-        property.gsub(/\\\./, '_____').split('.').reduce($results[test.hash]) do |memo, attr|
+      def evaluate(test, property, response=nil)
+        response ||= $results[test.hash]
+        property.gsub(/\\\./, '_____').split('.').reduce(response) do |memo, attr|
           if memo
-            attr = attr.gsub(/_____/, '.') if attr
+            if attr
+              attr = attr.gsub(/_____/, '.')
+              attr = $stash[attr] if attr.start_with? '$'
+            end
             memo = memo.is_a?(Hash) ? memo[attr] : memo[attr.to_i]
           end
           memo
@@ -222,38 +233,44 @@ module Elasticsearch
         skip = actions.select { |a| a['skip'] }.first
         $stderr.puts "SKIP: #{skip.inspect}" if ENV['DEBUG']
 
-        # Skip version
-        if skip && skip['skip']['version']
+        def skip_version(skip)
+          if skip && skip['skip']['version']
 
-          return skip['skip']['reason'] ? skip['skip']['reason'] : true if skip['skip']['version'] == 'all'
+            return skip['skip']['reason'] ? skip['skip']['reason'] : true if skip['skip']['version'] == 'all'
 
-          min, max = skip['skip']['version'].split('-').map(&:strip)
+            min, max = skip['skip']['version'].split('-').map(&:strip)
 
-          min_normalized = sprintf "%03d-%03d-%03d",
-                           *min.split('.')
-                               .map(&:to_i)
-                               .fill(0, min.split('.').length, 3-min.split('.').length)
+            min_normalized = sprintf "%03d-%03d-%03d",
+                             *min.split('.')
+                                 .map(&:to_i)
+                                 .fill(0, min.split('.').length, 3-min.split('.').length)
 
-          max_normalized = sprintf "%03d-%03d-%03d",
-                           *max.split('.')
-                               .map(&:to_i)
-                               .map(&:to_i)
-                               .fill(0, max.split('.').length, 3-max.split('.').length)
+            max_normalized = sprintf "%03d-%03d-%03d",
+                             *max.split('.')
+                                 .map(&:to_i)
+                                 .map(&:to_i)
+                                 .fill(0, max.split('.').length, 3-max.split('.').length)
 
-          es_normalized  = sprintf "%03d-%03d-%03d", *$es_version.split('.').map(&:to_i)
+            es_normalized  = sprintf "%03d-%03d-%03d", *$es_version.split('.').map(&:to_i)
 
-          if ( min.empty? || min_normalized <= es_normalized ) && ( max.empty? || max_normalized >= es_normalized )
-            return skip['skip']['reason'] ? skip['skip']['reason'] : true
-          end
+            if ( min.empty? || min_normalized <= es_normalized ) && ( max.empty? || max_normalized >= es_normalized )
+              return skip['skip']['reason'] ? skip['skip']['reason'] : true
+            end
 
-        # Skip features
-        elsif skip && skip['skip']['features']
-          if (skip['skip']['features'].split(',') & SKIP_FEATURES.split(',') ).size > 0
-            return skip['skip']['features']
+            return false
           end
         end
 
-        return false
+        def skip_features(skip)
+          if skip && skip['skip']['features']
+            skip_features = skip['skip']['features'].respond_to?(:split) ? skip['skip']['features'].split(',') : skip['skip']['features']
+            if ( skip_features & SKIP_FEATURES.split(',') ).size > 0
+              return skip['skip']['features']
+            end
+          end
+        end
+
+        return skip_version(skip) || skip_features(skip)
       end
 
       extend self
@@ -265,8 +282,9 @@ end
 
 include Elasticsearch::YamlTestSuite
 
-PATH    = Pathname(ENV['TEST_REST_API_SPEC'] || \
-          File.expand_path('../../../../tmp/elasticsearch/rest-api-spec/test', __FILE__))
+rest_api_test_source = $client.info['version']['number'] < '2' ? '../../../../tmp/elasticsearch/rest-api-spec/test' : '../../../../tmp/elasticsearch/rest-api-spec/src/main/resources/rest-api-spec/test'
+PATH    = Pathname(ENV.fetch('TEST_REST_API_SPEC', File.expand_path(rest_api_test_source, __FILE__)))
+
 suites  = Dir.glob(PATH.join('*')).map { |d| Pathname(d) }
 suites  = suites.select { |s| s.to_s =~ Regexp.new(ENV['FILTER']) } if ENV['FILTER']
 
@@ -278,8 +296,31 @@ suites.each do |suite|
     # --- Register context setup -------------------------------------------
     #
     setup do
-      $client.indices.delete index: '_all'
-      $client.indices.delete_template name: '*'
+      $helper_client.indices.delete index: '_all', ignore: 404
+      $helper_client.indices.delete_template name: '*', ignore: 404
+      $helper_client.snapshot.delete repository: 'test_repo_create_1',  snapshot: 'test_snapshot', ignore: 404
+      $helper_client.snapshot.delete repository: 'test_repo_restore_1', snapshot: 'test_snapshot', ignore: 404
+      $helper_client.snapshot.delete repository: 'test_cat_snapshots_1', snapshot: 'snap1', ignore: 404
+      $helper_client.snapshot.delete repository: 'test_cat_snapshots_1', snapshot: 'snap2', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_repo_create_1', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_repo_restore_1', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_repo_get_1', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_repo_get_2', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_repo_status_1', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_cat_repo_1', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_cat_repo_2', ignore: 404
+      $helper_client.snapshot.delete_repository repository: 'test_cat_snapshots_1', ignore: 404
+      # FIXME: This shouldn't be needed -------------
+      %w[
+        test_cat_repo_1_loc
+        test_cat_repo_2_loc
+        test_cat_snapshots_1_loc
+        test_repo_get_1_loc
+        test_repo_status_1_loc
+      ].each do |d|
+        FileUtils.rm_rf("/tmp/#{d}")
+      end
+      # ---------------------------------------------
       $results = {}
       $stash   = {}
     end
@@ -287,12 +328,18 @@ suites.each do |suite|
     # --- Register context teardown ----------------------------------------
     #
     teardown do
-      $client.indices.delete index: '_all'
+      $helper_client.indices.delete index: '_all', ignore: 404
     end
 
     files = Dir[suite.join('*.{yml,yaml}')]
     files.each do |file|
-      tests = YAML.load_documents File.new(file)
+      begin
+        tests = YAML.load_stream File.new(file)
+      rescue Exception => e
+        $stderr.puts "ERROR [#{e.class}] while loading [#{file}] file".ansi(:red)
+        # raise e
+        next
+      end
 
       # Extract setup actions
       setup_actions = tests.select { |t| t['setup'] }.first['setup'] rescue []
@@ -321,12 +368,39 @@ suites.each do |suite|
 
           # --- Register test setup -------------------------------------------
           setup do
-            actions.select { |a| a['setup'] }.first['setup'].each do |action|
-              next unless action['do']
-              api, arguments = action['do'].to_a.first
-              arguments      = Utils.symbolize_keys(arguments)
-              Runner.perform_api_call((test.to_s + '___setup'), api, arguments)
-            end
+            setup_actions = actions.select { |a| a['setup'] }
+            setup_actions.first['setup'].each do |action|
+              if action['do']
+                api, arguments = action['do'].to_a.first
+                arguments      = Utils.symbolize_keys(arguments)
+                Runner.perform_api_call((test.to_s + '___setup'), api, arguments)
+              end
+              if action['set']
+                stash = action['set']
+                property, variable = stash.to_a.first
+                result  = Runner.evaluate(test, property, $last_response)
+                $stderr.puts "STASH: '$#{variable}' => #{result.inspect}" if ENV['DEBUG']
+                Runner.set variable, result
+              end
+            end unless setup_actions.empty?
+          end
+
+          teardown do
+            teardown_actions = actions.select { |a| a['teardown'] }
+            teardown_actions.first['teardown'].each do |action|
+              if action['do']
+                api, arguments = action['do'].to_a.first
+                arguments      = Utils.symbolize_keys(arguments)
+                Runner.perform_api_call((test.to_s + '___teardown'), api, arguments)
+              end
+              if action['set']
+                stash = action['set']
+                property, variable = stash.to_a.first
+                result  = Runner.evaluate(test, property, $last_response)
+                $stderr.puts "STASH: '$#{variable}' => #{result.inspect}" if ENV['DEBUG']
+                Runner.set variable, result
+              end
+            end unless teardown_actions.empty?
           end
 
           # --- Register test method ------------------------------------------
@@ -335,11 +409,15 @@ suites.each do |suite|
               ref = ENV['TEST_BUILD_REF'].to_s.gsub(/origin\//, '') || 'master'
               $stderr.puts "https://github.com/elasticsearch/elasticsearch/blob/#{ref}/rest-api-spec/test/" \
                           + file.gsub(PATH.to_s, ''), ""
-              $stderr.puts YAML.dump(test)
+              $stderr.puts YAML.dump(test) if ENV['DEBUG']
             end
             actions.each do |action|
               $stderr.puts "ACTION: #{action.inspect}" if ENV['DEBUG']
 
+              # This check verifies that the YAML has correct indentation.
+              # See https://github.com/elastic/elasticsearch/issues/21980
+              raise "INVALID YAML: #{action.inspect}" if action.keys.size != 1
+
               case
 
                 # --- Perform action ------------------------------------------
@@ -360,18 +438,26 @@ suites.each do |suite|
 
                     if catch_exception
                       $stderr.puts "CATCH: '#{catch_exception}': #{e.inspect}" if ENV['DEBUG']
-                      case e
-                        when 'missing'
-                          assert_match /\[404\]/, e.message
-                        when 'conflict'
-                          assert_match /\[409\]/, e.message
-                        when 'request'
-                          assert_match /\[500\]/, e.message
-                        when 'param'
-                          raise ArgumentError, "NOT IMPLEMENTED"
-                        when /\/.+\//
-                          assert_match Regexp.new(catch_exception.tr('/', '')), e.message
+
+                      if 'param' == catch_exception
+                        assert_equal 'ArgumentError', e.class.to_s
+                      else
+                        if e.class.to_s =~ /Elasticsearch/
+                          case catch_exception
+                            when 'missing'
+                              assert_match /\[404\]/, e.message
+                            when 'conflict'
+                              assert_match /\[409\]/, e.message
+                            when 'request'
+                              assert_match /\[4\d\d\]|\[5\d\d\]/, e.message
+                            when /\/.+\//
+                              assert_match Regexp.new(catch_exception.tr('/', '')), e.message
+                          end
+                        else
+                          raise e
+                        end
                       end
+
                     else
                       raise e
                     end
@@ -386,8 +472,10 @@ suites.each do |suite|
 
                 when property = action['is_false']
                   result = Runner.evaluate(test, property)
-                  $stderr.puts "CHECK: Expected '#{property}' to be false, is: #{result.inspect}" if ENV['DEBUG']
-                  assert( !!! result, "Property '#{property}' should be false, is: #{result.inspect}")
+                  $stderr.puts "CHECK: Expected '#{property}' to be nil, false, 0 or empty string, is: #{result.inspect}" if ENV['DEBUG']
+                  assert_block "Property '#{property}' should be nil, false, 0 or empty string, but is: #{result.inspect}" do
+                    result.nil? || result == false || result == 0 || result == ''
+                  end
 
                 when a = action['match']
                   property, value = a.to_a.first
@@ -422,17 +510,24 @@ suites.each do |suite|
                   $stderr.puts "CHECK: Expected '#{property}' to be #{value}, is: #{length.inspect}" if ENV['DEBUG']
                   assert_equal(value, length)
 
-                when a = action['lt'] || action['gt']
-                  next
+                when a = action['lt'] || action['gt'] || action['lte'] || action['gte']
                   property, value = a.to_a.first
-                  operator        = action['lt'] ? '<' : '>'
+                  operator = case
+                    when action['lt']
+                      '<'
+                    when action['gt']
+                      '>'
+                    when action['lte']
+                      '<='
+                    when action['gte']
+                      '>='
+                  end
 
                   result  = Runner.evaluate(test, property)
                   message = "Expected '#{property}' to be #{operator} #{value}, is: #{result.inspect}"
 
                   $stderr.puts "CHECK: #{message}" if ENV['DEBUG']
-                  # operator == 'less than' ? assert(value.to_f < result.to_f, message) : assert(value.to_f > result.to_f, message)
-                  assert_operator result, operator.to_sym, value.to_i
+                  assert_operator result, operator.to_sym, Runner.fetch_or_return(value).to_i
 
                 when stash = action['set']
                   property, variable = stash.to_a.first
