@@ -36,14 +36,23 @@ module Elasticsearch
         #
         def to_hash
           if @block
-            call
+            call unless @block_called
+            @block_called = true
           else
-            @value << @args if @args
+            @value << @args if @args && !@args.empty? && ! @value.include?(@args)
           end
 
           @hash = @value.flatten
           @hash
         end
+
+        # Return whether the definition is empty
+        #
+        # @return [Boolean]
+        #
+        def empty?
+          to_hash.empty?
+        end
       end
     end
   end
