@@ -7,7 +7,11 @@ module Elasticsearch
 
         context "Search results pagination" do
           setup do
+            @client.indices.create index: 'test', body: {
+              mappings: { d: { properties: { title: { type: 'text', fields: { keyword: { type: 'keyword' } } } } } } }
+
             25.times { |i| @client.index index: 'test', type: 'd', id: i, body: { title: "Test #{sprintf('%03d', i)}" } }
+
             @client.indices.refresh index: 'test'
           end
 
@@ -23,10 +27,10 @@ module Elasticsearch
 
           should "move the offset" do
             response = @client.search index: 'test', body: search {
-              query { match(:title) { query 'test' and type 'phrase_prefix' } }
+              query { match(:title) { query 'test' } }
               size 5
               from 5
-              sort { by :title }
+              sort { by 'title.keyword' }
             }.to_hash
 
             assert_equal 25, response['hits']['total']
