@@ -17,10 +17,13 @@ module Elasticsearch
             mappings: {
               d: {
                 properties: {
-                  title: { type: 'string' },
-                  title_suggest: {
-                    type: 'completion',
-                    payloads: true
+                  title: { type: 'text' },
+                  suggest: {
+                    type: 'object',
+                    properties: {
+                      title:   { type: 'completion' },
+                      payload: { type: 'object', enabled: false }
+                    }
                   }
                 }
               }
@@ -29,32 +32,50 @@ module Elasticsearch
 
           @client.index index: 'test', type: 'd', id: '1', body: {
             title: 'One',
-            title_suggest: { input: ['one', 'uno', 'jedna'] }, output: 'ONE', payload: { id: '1' } }
+            suggest: {
+              title: { input: ['one', 'uno', 'jedna'] },
+              payload: { id: '1' }
+            }
+          }
           @client.index index: 'test', type: 'd', id: '2', body: {
             title: 'Two',
-            title_suggest: { input: ['two', 'due', 'dvě'] }, output: 'TWO', payload: { id: '2' } }
+            suggest: {
+              title: { input: ['two', 'due', 'dvě'] },
+              payload: { id: '2' }
+            }
+          }
           @client.index index: 'test', type: 'd', id: '3', body: {
             title: 'Three',
-            title_suggest: { input: ['three', 'tres', 'tři'] }, output: 'THREE', payload: { id: '3' } }
+            suggest: {
+              title: { input: ['three', 'tres', 'tři'] },
+              payload: { id: '3' }
+            }
+          }
           @client.indices.refresh index: 'test'
         end
 
         should "return suggestions" do
           s = search do
-            suggest :title, text: 't', completion: { field: 'title_suggest' }
+            suggest :title, text: 't', completion: { field: 'suggest.title' }
           end
 
           response = @client.search index: 'test', body: s.to_hash
-          assert_equal 4, response['suggest']['title'][0]['options'].size
+
+          assert_equal 2, response['suggest']['title'][0]['options'].size
+
+          assert_same_elements %w[2 3], response['suggest']['title'][0]['options'].map { |d| d['_source']['suggest']['payload']['id'] }
         end
 
         should "return a single suggestion" do
           s = search do
-            suggest :title, text: 'th', completion: { field: 'title_suggest' }
+            suggest :title, text: 'th', completion: { field: 'suggest.title' }
           end
 
           response = @client.search index: 'test', body: s.to_hash
+
           assert_equal 1, response['suggest']['title'][0]['options'].size
+
+          assert_same_elements %w[3], response['suggest']['title'][0]['options'].map { |d| d['_source']['suggest']['payload']['id'] }
         end
       end
     end
