@@ -5,14 +5,23 @@ if ENV['COVERAGE'] || ENV['CI']
   SimpleCov.start { add_filter "/test|test_" }
 end
 
+ELASTICSEARCH_HOSTS = if hosts = ENV['TEST_ES_SERVER'] || ENV['ELASTICSEARCH_HOSTS']
+                        hosts.split(',').map do |host|
+                          /(http\:\/\/)?(\S+)/.match(host)[2]
+                        end
+                      end.freeze
+
 at_exit { Elasticsearch::Test::IntegrationTestCase.__run_at_exit_hooks }
 
-require 'test/unit'
+require 'minitest/autorun'
 require 'shoulda-context'
 require 'mocha/setup'
 
 require 'minitest/reporters'
 Minitest::Reporters.use! Minitest::Reporters::SpecReporter.new
+# Minitest::Reporters.use! [ Minitest::Reporters::SpecReporter.new,
+#                            Minitest::Reporters::JUnitReporter.new,
+#                            Minitest::Reporters::HtmlReporter.new ]
 
 require 'elasticsearch'
 require 'elasticsearch/extensions/test/cluster'
@@ -22,7 +31,23 @@ require 'elasticsearch/dsl'
 
 module Elasticsearch
   module Test
-    class IntegrationTestCase < ::Test::Unit::TestCase
+    module Assertions
+      def assert_nothing_raised(*)
+        yield
+      end
+    end
+
+    class UnitTestCase < ::Minitest::Test
+      include Assertions
+      alias_method :assert_not_nil, :refute_nil
+      alias_method :assert_raise, :assert_raises
+    end
+
+    class IntegrationTestCase < ::Minitest::Test
+      include Assertions
+      alias_method :assert_not_nil, :refute_nil
+      alias_method :assert_raise, :assert_raises
+
       include Elasticsearch::Extensions::Test
       extend  StartupShutdown
 
@@ -38,7 +63,6 @@ module Elasticsearch
       end
 
       def setup
-        @port = (ENV['TEST_CLUSTER_PORT'] || 9250).to_i
 
         @logger =  Logger.new(STDERR)
         @logger.formatter = proc do |severity, datetime, progname, msg|
@@ -51,7 +75,7 @@ module Elasticsearch
           ANSI.ansi(severity[0] + ' ', color, :faint) + ANSI.ansi(msg, :white, :faint) + "\n"
         end
 
-        @client = Elasticsearch::Client.new host: "localhost:#{@port}", logger: @logger
+        @client = Elasticsearch::Client.new hosts: ELASTICSEARCH_HOSTS, logger: (ENV['QUIET'] ? nil : @logger)
         @version = @client.info['version']['number']
       end
 
