@@ -4,10 +4,20 @@ require 'pathname'
 require 'fileutils'
 
 require 'multi_json'
-require 'oj'
+
+begin
+  require 'oj'
+rescue LoadError
+  warn('The "oj" gem could not be loaded. JSON parsing and serialization performance may not be optimal.')
+end
+
+begin
+  require 'patron'
+rescue LoadError
+  warn('The "patron" gem could not be loaded. HTTP requests may not be performed optimally.')
+end
 
 require 'elasticsearch'
-require 'patron'
 
 module Backup
   module Database
