@@ -174,8 +174,30 @@ module Elasticsearch
                 -E logger.level=#{ENV['DEBUG'] ? 'DEBUG' : 'INFO'} \
                 #{arguments[:es_params]}
               COMMAND
+            },
+
+            '6.0' => lambda { |arguments, node_number|
+              <<-COMMAND.gsub(/                /, '').gsub(/\n$/, '')
+                #{arguments[:command]} \
+                -E cluster.name=#{arguments[:cluster_name]} \
+                -E node.name=#{arguments[:node_name]}-#{node_number} \
+                -E http.port=#{arguments[:port].to_i + (node_number-1)} \
+                -E path.data=#{arguments[:path_data]} \
+                -E path.logs=#{arguments[:path_logs]} \
+                -E cluster.routing.allocation.disk.threshold_enabled=false \
+                -E network.host=#{arguments[:network_host]} \
+                -E node.attr.testattr=test \
+                -E path.repo=/tmp \
+                -E repositories.url.allowed_urls=http://snapshot.test* \
+                -E discovery.zen.minimum_master_nodes=#{arguments[:number_of_nodes]-1} \
+                -E node.max_local_storage_nodes=#{arguments[:number_of_nodes]} \
+                -E logger.level=#{ENV['DEBUG'] ? 'DEBUG' : 'INFO'} \
+                #{arguments[:es_params]}
+              COMMAND
             }
           }
+          COMMANDS['7.0'] = COMMANDS['6.0'].clone
+          COMMANDS.freeze
 
           # Create a new instance of the Cluster class
           #
@@ -386,7 +408,7 @@ module Elasticsearch
                 '0.0.0.0'
               when /^2/
                 '_local_'
-              when /^5/
+              when /^5|^6|^7/
                 '_local_'
               else
                 raise RuntimeError, "Cannot determine default network host from version [#{version}]"
@@ -431,10 +453,10 @@ module Elasticsearch
             path_to_lib = File.dirname(arguments[:command]) + '/../lib/'
             version = if arguments[:version]
               arguments[:version]
-            elsif File.exist?(path_to_lib) && !(jar = Dir.entries(path_to_lib).select { |f| f.start_with? 'elasticsearch' }.first).nil?
+            elsif File.exist?(path_to_lib) && !(jar = Dir.entries(path_to_lib).select { |f| f =~ /^elasticsearch\-\d/ }.first).nil?
               __log "Determining version from [#{jar}]" if ENV['DEBUG']
-              if m = jar.match(/elasticsearch\-(\d+\.\d+\.\d+).*/)
-                m[1]
+              if m = jar.match(/elasticsearch\-(\S+-)?(?<version>\d+\.\d+\.\d+).*/)
+                m[:version]
               else
                 raise RuntimeError, "Cannot determine Elasticsearch version from jar [#{jar}]"
               end
@@ -461,15 +483,14 @@ module Elasticsearch
               begin
                 # First, try the new `--version` syntax...
                 __log "Running [#{arguments[:command]} --version] to determine version" if ENV['DEBUG']
-                rout, wout = IO.pipe
-                pid = Process.spawn("#{arguments[:command]} --version", out: wout)
+                io = IO.popen("#{arguments[:command]} --version")
+                pid = io.pid
 
                 Timeout::timeout(arguments[:timeout_version]) do
                   Process.wait(pid)
-                  wout.close unless wout.closed?
-                  output = rout.read unless rout.closed?
-                  rout.close unless rout.closed?
+                  output = io.read
                 end
+
               rescue Timeout::Error
                 # ...else, the old `-v` syntax
                 __log "Running [#{arguments[:command]} -v] to determine version" if ENV['DEBUG']
@@ -478,8 +499,7 @@ module Elasticsearch
                 if pid
                   Process.kill('INT', pid) rescue Errno::ESRCH # Most likely the process has terminated already
                 end
-                wout.close unless wout.closed?
-                rout.close unless rout.closed?
+                io.close unless io.closed?
               end
 
               STDERR.puts "> #{output}" if ENV['DEBUG']
@@ -504,6 +524,10 @@ module Elasticsearch
                 '2.0'
               when /^5\..*/
                 '5.0'
+              when /^6\..*/
+                '6.0'
+              when /^7\..*/
+                '7.0'
               else
                 raise RuntimeError, "Cannot determine major version from [#{version}]"
             end
