@@ -3,7 +3,7 @@ require 'pathname'
 
 require 'elasticsearch/extensions/test/cluster'
 
-class Elasticsearch::Extensions::TestClusterIntegrationTest < Test::Unit::TestCase
+class Elasticsearch::Extensions::TestClusterIntegrationTest < Elasticsearch::Test::IntegrationTestCase
   context "The Test::Cluster" do
     PATH_TO_BUILDS = if ENV['PATH_TO_BUILDS']
       Pathname(ENV['PATH_TO_BUILDS'])
@@ -17,24 +17,31 @@ class Elasticsearch::Extensions::TestClusterIntegrationTest < Test::Unit::TestCa
     end
 
     @builds = begin
-      PATH_TO_BUILDS.entries.reject { |f| f.to_s =~ /^\./ }
+      PATH_TO_BUILDS.entries.reject { |f| f.to_s =~ /^\./ }.sort
     rescue Errno::ENOENT
       []
     end
 
-    STDOUT.puts %Q|Builds: \n#{@builds.map { |b| "  * #{b}"}.join("\n")}|
+    STDOUT.puts %Q|Builds: \n#{@builds.map { |b| "  * #{b}"}.join("\n")}| unless ENV['QUIET']
 
     @builds.each do |build|
       should "start and stop #{build.to_s}" do
         puts ("----- #{build.to_s} " + "-"*(80-7-build.to_s.size)).to_s.ansi(:bold)
         begin
-          Elasticsearch::Extensions::Test::Cluster.start command: PATH_TO_BUILDS.join(build.join('bin/elasticsearch')).to_s
+          Elasticsearch::Extensions::Test::Cluster.start \
+            command: PATH_TO_BUILDS.join(build.join('bin/elasticsearch')).to_s,
+            port: 9260,
+            cluster_name: 'elasticsearch-ext-integration-test',
+            path_data: '/tmp/elasticsearch-ext-integration-test'
 
           # Index some data to create the data directory
-          client = Elasticsearch::Client.new host: "localhost:9250"
+          client = Elasticsearch::Client.new host: "localhost:9260"
           client.index index: 'test1', type: 'd', id: 1, body: { title: 'TEST' }
         ensure
-          Elasticsearch::Extensions::Test::Cluster.stop command: PATH_TO_BUILDS.join(build.join('bin/elasticsearch')).to_s
+          Elasticsearch::Extensions::Test::Cluster.stop \
+            command: PATH_TO_BUILDS.join(build.join('bin/elasticsearch')).to_s,
+            port: 9260,
+            cluster_name: 'elasticsearch-ext-integration-test'
         end
       end
     end
