@@ -8,7 +8,9 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
 
   class DummyTransport
     include Elasticsearch::Transport::Transport::Base
-    def __build_connections; hosts; end
+    def __build_connection(host, options={}, block=nil)
+      Elasticsearch::Transport::Transport::Connections::Connection.new :host => host, :connection => Object.new
+    end
   end
 
   class DummyTransportPerformer < DummyTransport
@@ -24,9 +26,9 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
   end
 
   context "Transport::Base" do
-    should "raise exception when it doesn't implement __build_connections" do
+    should "raise exception when it doesn't implement __build_connection" do
       assert_raise NoMethodError do
-        EmptyTransport.new.__build_connections
+        EmptyTransport.new.__build_connection({ :host => 'foo'}, {})
       end
     end
 
@@ -75,6 +77,11 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
       should "combine authentication credentials" do
         assert_equal 'http://U:P@myhost:8080', @transport.__full_url(@basic_parts.merge :user => 'U', :password => 'P')
       end
+
+      should "escape the username and password" do
+        assert_equal 'http://user%40domain:foo%2Fbar@myhost:8080',
+                     @transport.__full_url(@basic_parts.merge :user => 'user@domain', :password => 'foo/bar')
+      end
     end
   end
 
@@ -178,6 +185,17 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
       assert_equal 'FOOBAR', response.body
     end
 
+    should "not deserialize an empty response body" do
+      @transport.expects(:get_connection).returns(stub_everything :failures => 1)
+      @transport.serializer.expects(:load).never
+      response = @transport.perform_request 'GET', '/' do
+                   Elasticsearch::Transport::Transport::Response.new 200, '', {"content-type" => 'application/json'}
+                 end
+
+      assert_instance_of Elasticsearch::Transport::Transport::Response, response
+      assert_equal '', response.body
+    end
+
     should "serialize non-String objects" do
       @transport.serializer.expects(:dump).times(3)
       @transport.__convert_to_json({:foo => 'bar'})
@@ -228,6 +246,21 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
       end
     end
 
+    should "not raise an error when the :ignore argument has been passed" do
+      @transport.stubs(:get_connection).returns(stub_everything :failures => 1)
+
+      assert_raise Elasticsearch::Transport::Transport::Errors::BadRequest do
+        @transport.perform_request 'GET', '/' do
+          Elasticsearch::Transport::Transport::Response.new 400, 'CLIENT ERROR'
+        end
+      end
+
+      # No `BadRequest` error
+      @transport.perform_request 'GET', '/', :ignore => 400 do
+        Elasticsearch::Transport::Transport::Response.new 400, 'CLIENT ERROR'
+      end
+    end
+
     should "mark the connection as dead on failure" do
       c = stub_everything :failures => 1
       @transport.expects(:get_connection).returns(c)
@@ -296,6 +329,53 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
     end
   end unless RUBY_1_8
 
+  context "performing a request with retry on status" do
+    setup do
+      DummyTransportPerformer.any_instance.stubs(:connections).returns(stub :get_connection => stub_everything(:failures => 1))
+
+      logger = Logger.new(STDERR)
+      logger.level = Logger::DEBUG
+      DummyTransportPerformer.any_instance.stubs(:logger).returns(logger)
+      @block = Proc.new { |c, u| puts "ERROR" }
+    end
+
+    should "not retry when the status code does not match" do
+      @transport = DummyTransportPerformer.new :options => { :retry_on_status => 500 }
+      assert_equal [500], @transport.instance_variable_get(:@retry_on_status)
+
+      @block.expects(:call).
+             returns(Elasticsearch::Transport::Transport::Response.new 400, 'Bad Request').
+             times(1)
+
+      @transport.logger.
+          expects(:warn).
+          with( regexp_matches(/Attempt \d to get response/) ).
+          never
+
+      assert_raise Elasticsearch::Transport::Transport::Errors::BadRequest do
+        @transport.perform_request('GET', '/', {}, nil, &@block)
+      end
+    end
+
+    should "retry when the status code does match" do
+      @transport = DummyTransportPerformer.new :options => { :retry_on_status => 500 }
+      assert_equal [500], @transport.instance_variable_get(:@retry_on_status)
+
+      @block.expects(:call).
+             returns(Elasticsearch::Transport::Transport::Response.new 500, 'Internal Error').
+             times(4)
+
+      @transport.logger.
+          expects(:warn).
+          with( regexp_matches(/Attempt \d to get response/) ).
+          times(4)
+
+      assert_raise Elasticsearch::Transport::Transport::Errors::InternalServerError do
+        @transport.perform_request('GET', '/', &@block)
+      end
+    end
+  end  unless RUBY_1_8
+
   context "logging" do
     setup do
       @transport = DummyTransportPerformer.new :options => { :logger => Logger.new('/dev/null') }
@@ -323,7 +403,24 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
                  end
     end
 
-    should "log a failed Elasticsearch request" do
+    should "sanitize password in the URL" do
+      fake_connection = stub :full_url => 'http://user:password@localhost:9200/_search?size=1',
+                             :host     => 'localhost',
+                             :connection => stub_everything,
+                             :failures => 0,
+                             :healthy! => true
+      @transport.stubs(:get_connection).returns(fake_connection)
+
+      @transport.logger.expects(:info).with do |message|
+        assert_match /http:\/\/user:\*{1,15}@localhost\:9200/, message
+        true
+      end
+
+
+      @transport.perform_request('GET', '/') {Elasticsearch::Transport::Transport::Response.new 200, '{"foo":"bar"}' }
+    end
+
+    should "log a failed Elasticsearch request as fatal" do
       @block = Proc.new { |c, u| puts "ERROR" }
       @block.expects(:call).returns(Elasticsearch::Transport::Transport::Response.new 500, 'ERROR')
 
@@ -335,6 +432,17 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
       end
     end unless RUBY_1_8
 
+    should "not log a failed Elasticsearch request as fatal" do
+      @block = Proc.new { |c, u| puts "ERROR" }
+      @block.expects(:call).returns(Elasticsearch::Transport::Transport::Response.new 500, 'ERROR')
+
+      @transport.expects(:__log).once
+      @transport.logger.expects(:fatal).never
+
+      # No `BadRequest` error
+      @transport.perform_request('POST', '_search', :ignore => 500, &@block)
+    end unless RUBY_1_8
+
     should "log and re-raise a Ruby exception" do
       @block = Proc.new { |c, u| puts "ERROR" }
       @block.expects(:call).raises(Exception)
@@ -419,6 +527,50 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
         @transport.reload_connections!
       end
     end
+
+    should "keep existing connections" do
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 } ], :options => { :http => {} }
+      assert_equal 1, @transport.connections.size
+
+      old_connection_id = @transport.connections.first.object_id
+
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 },
+                                                   { :host => 'node2', :port => 2 } ],
+                                       :options => { :http => {} }
+
+      assert_equal 2, @transport.connections.size
+      assert_equal old_connection_id, @transport.connections.first.object_id
+    end
+
+    should "remove dead connections" do
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 },
+                                                   { :host => 'node2', :port => 2 } ],
+                                       :options => { :http => {} }
+      assert_equal 2, @transport.connections.size
+
+      @transport.connections[1].dead!
+
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 } ], :options => { :http => {} }
+
+      assert_equal 1, @transport.connections.size
+      assert_equal 1, @transport.connections.all.size
+    end
+
+    should "not duplicate connections" do
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 },
+                                                   { :host => 'node2', :port => 2 } ],
+                                       :options => { :http => {} }
+      assert_equal 2, @transport.connections.size
+
+      @transport.connections[0].dead!
+
+      @transport.__rebuild_connections :hosts => [ { :host => 'node1', :port => 1 },
+                                                   { :host => 'node2', :port => 2 } ],
+                                       :options => { :http => {} }
+
+      assert_equal 2, @transport.connections.all.size
+      assert_equal 1, @transport.connections.size
+    end
   end
 
   context "rebuilding connections" do
@@ -426,10 +578,18 @@ class Elasticsearch::Transport::Transport::BaseTest < Test::Unit::TestCase
       @transport = DummyTransport.new
     end
 
+    should "close connections" do
+      @transport.expects(:__close_connections)
+      @transport.__rebuild_connections :hosts => [ { :scheme => 'http', :host => 'foo', :port => 1 } ], :options => { :http => {} }
+    end
+
     should "should replace the connections" do
-      assert_equal [], @transport.connections
-      @transport.__rebuild_connections :hosts => ['foo', 'bar']
-      assert_equal ['foo', 'bar'], @transport.connections
+      assert_equal 0, @transport.connections.size
+
+      @transport.__rebuild_connections :hosts => [{ :scheme => 'http', :host => 'foo', :port => 1 }],
+                                       :options => { :http => {} }
+
+      assert_equal 1, @transport.connections.size
     end
   end
 
